jactorch.graph.variable
=======================

.. automodule:: jactorch.graph.variable

   
   
   

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      new_var_with
      var_from_list
      var_with
   
   

   
   
   











.. rubric:: Functions

.. autofunction:: new_var_with

.. autofunction:: var_from_list

.. autofunction:: var_with


